@@ -20,19 +20,18 @@
 #define PKGLIB_ACQUIRE_ITEM_H
 
 #include <apt-pkg/acquire.h>
-#include <apt-pkg/indexfile.h>
 #include <apt-pkg/hashes.h>
-#include <apt-pkg/weakptr.h>
+#include <apt-pkg/indexfile.h>
 #include <apt-pkg/pkgcache.h>
-#include <apt-pkg/cacheiterators.h>
+#include <apt-pkg/weakptr.h>
 
+#include <map>
 #include <string>
 #include <vector>
-#include <map>
 
 #ifndef APT_8_CLEANER_HEADERS
-#include <apt-pkg/sourcelist.h>
 #include <apt-pkg/pkgrecords.h>
+#include <apt-pkg/sourcelist.h>
 #endif
 
 /** \addtogroup acquire
@@ -686,6 +685,20 @@ class APT_HIDDEN pkgAcqIndex : public pkgAcqBaseIndex
              std::string const &Message, pkgAcquire::MethodConfig const * const Cnf);
 };
 									/*}}}*/
+struct APT_HIDDEN DiffInfo {						/*{{{*/
+   /** The filename of the diff. */
+   std::string file;
+
+   /** The hashes of the file after the diff is applied */
+   HashStringList result_hashes;
+
+   /** The hashes of the diff */
+   HashStringList patch_hashes;
+
+   /** The hashes of the compressed diff */
+   HashStringList download_hashes;
+};
+									/*}}}*/
 /** \brief An item that is responsible for fetching an index file of	{{{
  *  package list diffs and starting the package list's download.
  *
@@ -699,6 +712,8 @@ class APT_HIDDEN pkgAcqDiffIndex : public pkgAcqIndex
 {
    void * const d;
    std::vector<pkgAcqIndexMergeDiffs*> * diffs;
+   std::vector<DiffInfo> available_patches;
+   bool pdiff_merge;
 
  protected:
    /** \brief If \b true, debugging information will be written to std::clog. */
@@ -718,6 +733,7 @@ class APT_HIDDEN pkgAcqDiffIndex : public pkgAcqIndex
  public:
    // Specialized action members
    virtual void Failed(std::string const &Message, pkgAcquire::MethodConfig const * const Cnf) APT_OVERRIDE;
+   virtual bool VerifyDone(std::string const &Message, pkgAcquire::MethodConfig const * const Cnf) APT_OVERRIDE;
    virtual void Done(std::string const &Message, HashStringList const &Hashes,
 		     pkgAcquire::MethodConfig const * const Cnf) APT_OVERRIDE;
    virtual std::string DescURI() const APT_OVERRIDE {return Target.URI + "Index";};
@@ -752,20 +768,6 @@ class APT_HIDDEN pkgAcqDiffIndex : public pkgAcqIndex
    APT_HIDDEN void QueueOnIMSHit() const;
 };
 									/*}}}*/
-struct APT_HIDDEN DiffInfo {						/*{{{*/
-   /** The filename of the diff. */
-   std::string file;
-
-   /** The hashes of the file after the diff is applied */
-   HashStringList result_hashes;
-
-   /** The hashes of the diff */
-   HashStringList patch_hashes;
-
-   /** The hashes of the compressed diff */
-   HashStringList download_hashes;
-};
-									/*}}}*/
 /** \brief An item that is responsible for fetching client-merge patches {{{
  *  that need to be applied to a given package index file.
  *
