@@ -19,52 +19,52 @@
 // Include Files							/*{{{*/
 #include <config.h>
 
-#include <apt-pkg/fileutl.h>
-#include <apt-pkg/strutl.h>
-#include <apt-pkg/error.h>
-#include <apt-pkg/sptr.h>
 #include <apt-pkg/aptconfiguration.h>
 #include <apt-pkg/configuration.h>
+#include <apt-pkg/error.h>
+#include <apt-pkg/fileutl.h>
 #include <apt-pkg/macros.h>
+#include <apt-pkg/sptr.h>
+#include <apt-pkg/strutl.h>
 
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <iostream>
+#include <string>
+#include <vector>
 #include <ctype.h>
+#include <dirent.h>
+#include <errno.h>
+#include <fcntl.h>
+#include <glob.h>
+#include <grp.h>
+#include <pwd.h>
+#include <signal.h>
 #include <stdarg.h>
 #include <stddef.h>
 #include <sys/select.h>
-#include <time.h>
-#include <string>
-#include <vector>
-#include <cstdlib>
-#include <cstring>
-#include <cstdio>
-#include <iostream>
-#include <unistd.h>
-#include <fcntl.h>
 #include <sys/stat.h>
 #include <sys/time.h>
 #include <sys/wait.h>
-#include <dirent.h>
-#include <signal.h>
-#include <errno.h>
-#include <glob.h>
-#include <pwd.h>
-#include <grp.h>
+#include <time.h>
+#include <unistd.h>
 
-#include <set>
 #include <algorithm>
 #include <memory>
+#include <set>
 
 #ifdef HAVE_ZLIB
-	#include <zlib.h>
+#include <zlib.h>
 #endif
 #ifdef HAVE_BZ2
-	#include <bzlib.h>
+#include <bzlib.h>
 #endif
 #ifdef HAVE_LZMA
-	#include <lzma.h>
+#include <lzma.h>
 #endif
 #ifdef HAVE_LZ4
-	#include <lz4frame.h>
+#include <lz4frame.h>
 #endif
 #include <endian.h>
 #include <stdint.h>
@@ -175,6 +175,21 @@ bool CopyFile(FileFd &From,FileFd &To)
 	 return false;
    } while (ToRead != 0);
 
+   return true;
+}
+									/*}}}*/
+bool RemoveFileAt(char const * const Function, int const dirfd, std::string const &FileName)/*{{{*/
+{
+   if (FileName == "/dev/null")
+      return true;
+   errno = 0;
+   if (unlinkat(dirfd, FileName.c_str(), 0) != 0)
+   {
+      if (errno == ENOENT)
+	 return true;
+
+      return _error->WarningE(Function,_("Problem unlinking the file %s"), FileName.c_str());
+   }
    return true;
 }
 									/*}}}*/
@@ -387,7 +402,10 @@ std::vector<string> GetListOfFilesInDir(string const &Dir, std::vector<string> c
    DIR *D = opendir(Dir.c_str());
    if (D == 0) 
    {
-      _error->Errno("opendir",_("Unable to read %s"),Dir.c_str());
+      if (errno == EACCES)
+	 _error->WarningE("opendir", _("Unable to read %s"), Dir.c_str());
+      else
+	 _error->Errno("opendir", _("Unable to read %s"), Dir.c_str());
       return List;
    }
 
@@ -2478,15 +2496,35 @@ bool FileFd::Read(int const Fd, void *To, unsigned long long Size, unsigned long
 }
 									/*}}}*/
 // FileFd::ReadLine - Read a complete line from the file		/*{{{*/
-// ---------------------------------------------------------------------
-/* Beware: This method can be quite slow for big buffers on UNcompressed
-   files because of the naive implementation! */
 char* FileFd::ReadLine(char *To, unsigned long long const Size)
 {
    *To = '\0';
    if (d == nullptr || Failed())
       return nullptr;
    return d->InternalReadLine(To, Size);
+}
+bool FileFd::ReadLine(std::string &To)
+{
+   To.clear();
+   if (d == nullptr || Failed())
+      return false;
+   constexpr size_t buflen = 4096;
+   char buffer[buflen];
+   size_t len;
+   do
+   {
+      if (d->InternalReadLine(buffer, buflen) == nullptr)
+	 return false;
+      len = strlen(buffer);
+      To.append(buffer, len);
+   } while (len == buflen - 1 && buffer[len - 2] != '\n');
+   // remove the newline at the end
+   auto const i = To.find_last_not_of("\r\n");
+   if (i == std::string::npos)
+      To.clear();
+   else
+      To.erase(i + 1);
+   return true;
 }
 									/*}}}*/
 // FileFd::Flush - Flush the file  					/*{{{*/
@@ -2832,7 +2870,7 @@ std::string GetTempDir(std::string const &User)
 FileFd* GetTempFile(std::string const &Prefix, bool ImmediateUnlink, FileFd * const TmpFd)	/*{{{*/
 {
    char fn[512];
-   FileFd * const Fd = TmpFd == NULL ? new FileFd() : TmpFd;
+   FileFd * const Fd = TmpFd == nullptr ? new FileFd() : TmpFd;
 
    std::string const tempdir = GetTempDir();
    snprintf(fn, sizeof(fn), "%s/%s.XXXXXX",
@@ -2843,12 +2881,16 @@ FileFd* GetTempFile(std::string const &Prefix, bool ImmediateUnlink, FileFd * co
    if (fd < 0)
    {
       _error->Errno("GetTempFile",_("Unable to mkstemp %s"), fn);
-      return NULL;
+      if (TmpFd == nullptr)
+	 delete Fd;
+      return nullptr;
    }
    if (!Fd->OpenDescriptor(fd, FileFd::ReadWrite, FileFd::None, true))
    {
       _error->Errno("GetTempFile",_("Unable to write to %s"),fn);
-      return NULL;
+      if (TmpFd == nullptr)
+	 delete Fd;
+      return nullptr;
    }
    return Fd;
 }
@@ -3085,3 +3127,15 @@ bool DropPrivileges()							/*{{{*/
    return true;
 }
 									/*}}}*/
+bool OpenConfigurationFileFd(std::string const &File, FileFd &Fd) /*{{{*/
+{
+   int const fd = open(File.c_str(), O_RDONLY | O_CLOEXEC | O_NOCTTY);
+   if (fd == -1)
+      return _error->WarningE("open", _("Unable to read %s"), File.c_str());
+   APT::Configuration::Compressor none(".", "", "", nullptr, nullptr, 0);
+   if (Fd.OpenDescriptor(fd, FileFd::ReadOnly, none, true) == false)
+      return false;
+   Fd.SetFileName(File);
+   return true;
+}
+									/*}}}*/
