@@ -17,30 +17,30 @@
 // Includes								/*{{{*/
 #include <config.h>
 
-#include <apt-pkg/strutl.h>
-#include <apt-pkg/fileutl.h>
 #include <apt-pkg/error.h>
+#include <apt-pkg/fileutl.h>
+#include <apt-pkg/strutl.h>
 
-#include <array>
 #include <algorithm>
+#include <array>
 #include <iomanip>
 #include <locale>
 #include <sstream>
-#include <string>
 #include <sstream>
+#include <string>
 #include <vector>
 
-#include <stddef.h>
-#include <stdlib.h>
-#include <time.h>
 #include <ctype.h>
-#include <string.h>
-#include <stdio.h>
-#include <unistd.h>
-#include <regex.h>
 #include <errno.h>
-#include <stdarg.h>
 #include <iconv.h>
+#include <regex.h>
+#include <stdarg.h>
+#include <stddef.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <time.h>
+#include <unistd.h>
 
 #include <apti18n.h>
 									/*}}}*/
@@ -1482,7 +1482,7 @@ string StripEpoch(const string &VerStr)
    standard tolower/toupper and as a bonus avoids problems with different
    locales - we only operate on ascii chars anyway. */
 #undef tolower_ascii
-int tolower_ascii(int const c) APT_CONST APT_COLD;
+int tolower_ascii(int const c) APT_PURE APT_COLD;
 int tolower_ascii(int const c)
 {
    return tolower_ascii_inline(c);
@@ -1496,7 +1496,7 @@ int tolower_ascii(int const c)
    standard isspace() and as a bonus avoids problems with different
    locales - we only operate on ascii chars anyway. */
 #undef isspace_ascii
-int isspace_ascii(int const c) APT_CONST APT_COLD;
+int isspace_ascii(int const c) APT_PURE APT_COLD;
 int isspace_ascii(int const c)
 {
    return isspace_ascii_inline(c);
