@@ -11,20 +11,20 @@
 
 #include <apt-pkg/cachefile.h>
 #include <apt-pkg/configuration.h>
+#include <apt-pkg/debsystem.h>
 #include <apt-pkg/depcache.h>
 #include <apt-pkg/dpkgpm.h>
-#include <apt-pkg/debsystem.h>
 #include <apt-pkg/error.h>
 #include <apt-pkg/fileutl.h>
 #include <apt-pkg/install-progress.h>
-#include <apt-pkg/packagemanager.h>
-#include <apt-pkg/strutl.h>
-#include <apt-pkg/statechanges.h>
-#include <apt-pkg/cacheiterators.h>
 #include <apt-pkg/macros.h>
+#include <apt-pkg/packagemanager.h>
 #include <apt-pkg/pkgcache.h>
+#include <apt-pkg/statechanges.h>
+#include <apt-pkg/strutl.h>
 #include <apt-pkg/version.h>
 
+#include <dirent.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <grp.h>
@@ -37,9 +37,8 @@
 #include <sys/select.h>
 #include <sys/stat.h>
 #include <sys/time.h>
-#include <sys/wait.h>
 #include <sys/types.h>
-#include <dirent.h>
+#include <sys/wait.h>
 #include <termios.h>
 #include <time.h>
 #include <unistd.h>
@@ -49,14 +48,14 @@
 #include <cstring>
 #include <iostream>
 #include <map>
+#include <numeric>
 #include <set>
+#include <sstream>
 #include <string>
 #include <type_traits>
-#include <utility>
 #include <unordered_set>
+#include <utility>
 #include <vector>
-#include <sstream>
-#include <numeric>
 
 #include <apti18n.h>
 									/*}}}*/
@@ -985,7 +984,7 @@ void pkgDPkgPM::WriteHistoryTag(string const &tag, string value)
 // DPkgPM::OpenLog							/*{{{*/
 bool pkgDPkgPM::OpenLog()
 {
-   string const logfile_name =  _config->FindFile("Dir::Log::Terminal");
+   string const logfile_name =  _config->FindFile("Dir::Log::Terminal", "/dev/null");
    string logdir = flNotFile(logfile_name);
    if(CreateAPTDirectoryIfNeeded(logdir, logdir) == false)
       // FIXME: use a better string after freeze
@@ -999,7 +998,7 @@ bool pkgDPkgPM::OpenLog()
    strftime(timestr, sizeof(timestr), "%F  %T", tmp);
 
    // open terminal log
-   if (!logfile_name.empty())
+   if (logfile_name != "/dev/null")
    {
       d->term_out = fopen(logfile_name.c_str(),"a");
       if (d->term_out == NULL)
@@ -1019,11 +1018,11 @@ bool pkgDPkgPM::OpenLog()
    }
 
    // write your history
-   string const history_name = _config->FindFile("Dir::Log::History");
+   string const history_name = _config->FindFile("Dir::Log::History", "/dev/null");
    string logdir2 = flNotFile(logfile_name);
    if(logdir != logdir2 && CreateAPTDirectoryIfNeeded(logdir2, logdir2) == false)
       return _error->Error(_("Directory '%s' missing"), logdir.c_str());
-   if (!history_name.empty())
+   if (history_name != "/dev/null")
    {
       d->history_out = fopen(history_name.c_str(),"a");
       if (d->history_out == NULL)
@@ -2351,8 +2350,8 @@ void pkgDPkgPM::WriteApportReport(const char *pkgpath, const char *errormsg)
       fflush(d->term_out);
 
    // attach terminal log it if we have it
-   string logfile_name = _config->FindFile("Dir::Log::Terminal");
-   if (!logfile_name.empty())
+   string logfile_name = _config->FindFile("Dir::Log::Terminal", "/dev/null");
+   if (logfile_name != "/dev/null")
    {
       FILE *log = NULL;
 
@@ -2369,8 +2368,8 @@ void pkgDPkgPM::WriteApportReport(const char *pkgpath, const char *errormsg)
    }
 
    // attach history log it if we have it
-   string histfile_name = _config->FindFile("Dir::Log::History");
-   if (!histfile_name.empty())
+   string histfile_name = _config->FindFile("Dir::Log::History", "/dev/null");
+   if (histfile_name != "/dev/null")
    {
       fprintf(report, "DpkgHistoryLog:\n");
       FILE* log = fopen(histfile_name.c_str(),"r");
