@@ -8,34 +8,33 @@
    ##################################################################### */
 									/*}}}*/
 // Include Files							/*{{{*/
-#include<config.h>
+#include <config.h>
 
+#include <apt-pkg/aptconfiguration.h>
+#include <apt-pkg/cachefile.h>
+#include <apt-pkg/cacheset.h>
+#include <apt-pkg/configuration.h>
 #include <apt-pkg/depcache.h>
-#include <apt-pkg/versionmatch.h>
-#include <apt-pkg/version.h>
 #include <apt-pkg/error.h>
 #include <apt-pkg/fileutl.h>
-#include <apt-pkg/strutl.h>
-#include <apt-pkg/configuration.h>
-#include <apt-pkg/aptconfiguration.h>
-#include <apt-pkg/tagfile.h>
-#include <apt-pkg/progress.h>
-#include <apt-pkg/cacheset.h>
-#include <apt-pkg/pkgcache.h>
-#include <apt-pkg/cacheiterators.h>
-#include <apt-pkg/prettyprinters.h>
-#include <apt-pkg/cachefile.h>
 #include <apt-pkg/macros.h>
+#include <apt-pkg/pkgcache.h>
+#include <apt-pkg/prettyprinters.h>
+#include <apt-pkg/progress.h>
+#include <apt-pkg/strutl.h>
+#include <apt-pkg/tagfile.h>
+#include <apt-pkg/version.h>
+#include <apt-pkg/versionmatch.h>
 
-#include <stdio.h>
-#include <string.h>
+#include <algorithm>
+#include <iostream>
 #include <list>
+#include <set>
 #include <string>
 #include <utility>
 #include <vector>
-#include <algorithm>
-#include <iostream>
-#include <set>
+#include <stdio.h>
+#include <string.h>
 
 #include <sys/stat.h>
 
@@ -183,7 +182,7 @@ bool pkgDepCache::readStateFile(OpProgress * const Prog)		/*{{{*/
    FileFd state_file;
    string const state = _config->FindFile("Dir::State::extended_states");
    if(RealFileExists(state)) {
-      state_file.Open(state, FileFd::ReadOnly);
+      state_file.Open(state, FileFd::ReadOnly, FileFd::Extension);
       off_t const file_size = state_file.Size();
       if(Prog != NULL)
 	 Prog->OverallProgress(0, file_size, 1,
@@ -245,16 +244,16 @@ bool pkgDepCache::writeStateFile(OpProgress * const /*prog*/, bool const Install
    // if it does not exist, create a empty one
    if(!RealFileExists(state))
    {
-      StateFile.Open(state, FileFd::WriteAtomic);
+      StateFile.Open(state, FileFd::WriteAtomic, FileFd::Extension);
       StateFile.Close();
    }
 
    // open it
-   if(!StateFile.Open(state, FileFd::ReadOnly))
+   if (!StateFile.Open(state, FileFd::ReadOnly, FileFd::Extension))
       return _error->Error(_("Failed to open StateFile %s"),
 			   state.c_str());
 
-   FileFd OutFile(state, FileFd::ReadWrite | FileFd::Atomic);
+   FileFd OutFile(state, FileFd::ReadWrite | FileFd::Atomic, FileFd::Extension);
    if (OutFile.IsOpen() == false || OutFile.Failed() == true)
       return _error->Error(_("Failed to write temporary StateFile %s"), state.c_str());
 
@@ -1783,7 +1782,7 @@ bool pkgDepCache::Policy::IsImportantDep(DepIterator const &Dep) const
 	 return true;
       // we support a special mode to only install-recommends for certain
       // sections
-      // FIXME: this is a meant as a temporarly solution until the
+      // FIXME: this is a meant as a temporary solution until the
       //        recommends are cleaned up
       const char *sec = Dep.ParentVer().Section();
       if (sec && ConfigValueInSubTree("APT::Install-Recommends-Sections", sec))
@@ -1796,11 +1795,11 @@ bool pkgDepCache::Policy::IsImportantDep(DepIterator const &Dep) const
 }
 									/*}}}*/
 // Policy::GetPriority - Get the priority of the package pin		/*{{{*/
-APT_CONST signed short pkgDepCache::Policy::GetPriority(pkgCache::PkgIterator const &/*Pkg*/)
+APT_PURE signed short pkgDepCache::Policy::GetPriority(pkgCache::PkgIterator const &/*Pkg*/)
 { return 0; }
-APT_CONST signed short pkgDepCache::Policy::GetPriority(pkgCache::VerIterator const &/*Ver*/, bool /*ConsiderFiles*/)
+APT_PURE signed short pkgDepCache::Policy::GetPriority(pkgCache::VerIterator const &/*Ver*/, bool /*ConsiderFiles*/)
 { return 0; }
-APT_CONST signed short pkgDepCache::Policy::GetPriority(pkgCache::PkgFileIterator const &/*File*/)
+APT_PURE signed short pkgDepCache::Policy::GetPriority(pkgCache::PkgFileIterator const &/*File*/)
 { return 0; }
 									/*}}}*/
 pkgDepCache::InRootSetFunc *pkgDepCache::GetRootSetFunc()		/*{{{*/
